﻿/*
  Antenna House PDF Tool API V6.0
  .Net Interface sample program

  概要：しおりの追加
  　　　サンプルPDFにしおり・階層化したしおり・URLにジャンプするしおりを追加します。
  Copyright (C) 2018- Antenna House, Inc. All rights reserved.
  Antenna House is a trademark of [Antenna House, Inc.]

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

using PdfTkNet;
using System;

namespace cookbook
{
    public class AppendOutline
    {
        /**
     * @param args the command line arguments
     */
        public static void Main(String[] args)
        {
            if (args.Length < 2)
            {
                Console.WriteLine("usage: AppendOutline in-pdf-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    using (PtlOutline outlineRoot = doc.getRootOutline()) //ルートアウトラインの取得
                    {
                        // しおりの追加
                        createOutline(outlineRoot);
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine("PtlException : ErrorCode = " + pex.getErrorCode() +
                                   "\n  " + pex.getErrorMessage());
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                Console.WriteLine(ex.StackTrace);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

        public static void createOutline(PtlOutline outlineRoot)
        {
            using (PtlOutline outlineActionGoToTop = new PtlOutline())
            {
                outlineActionGoToTop.setTitle("PDFにしおりを付ける");
                // アクション
                // PtlActionGoTo : GoToアクション<現在のドキュメント内の宛先へ移動>
                using (PtlActionGoTo actionGoTo = new PtlActionGoTo())
                using (PtlDestFit destFit = new PtlDestFit())  // PtlDestFit : Fit型
                {
                    // 宛先ページの設定(ページ番号は0ベース)
                    destFit.setPageNumber(0);
                    // 宛先の設定
                    actionGoTo.setDest(destFit);
                    // アクションの設定
                    outlineActionGoToTop.setAction(actionGoTo);
                }
                // アウトラインタイトルの色を設定
                using (PtlColorDeviceRGB color = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f))
                {
                    outlineActionGoToTop.setColor(color);
                }
                // アウトラインフラグを設定 (FLAG_BOLD : 太字)
                outlineActionGoToTop.setFlags(PtlOutline.ITEM_FLAG.FLAG_BOLD);
                // PDF表示時の子アウトラインをオープンするかどうかの設定

                outlineActionGoToTop.setOpen(true);
                // 子アウトラインの追加
                outlineRoot.appendLastChild(outlineActionGoToTop);

                using (PtlOutline outlineActionGoTo2 = new PtlOutline())
                {
                    outlineActionGoTo2.setTitle("Bookmark sample-1");
                    // アクション
                    // PtlActionGoTo : GoToアクション<現在のドキュメント内の宛先へ移動>
                    using (PtlActionGoTo actionGoTo2 = new PtlActionGoTo())
                    using (PtlDestFitH destFitH = new PtlDestFitH()) // PtlDestFitH : FitH型
                    {
                        // 宛先ページの設定(ページ番号は0ベース)
                        destFitH.setPageNumber(1);
                        // topの設定(本文の文章がちょうど一番上に来るように調整)
                        destFitH.setTop(245);
                        // 宛先の設定
                        actionGoTo2.setDest(destFitH);
                        // アクションの設定
                        outlineActionGoTo2.setAction(actionGoTo2);
                    }
                    // アウトラインタイトルの色を設定
                    using (PtlColorDeviceRGB color = new PtlColorDeviceRGB(0.0f, 0.5f, 0.0f))
                    {
                        outlineActionGoTo2.setColor(color);
                    }
                    // アウトラインフラグを設定（FLAG_NORMAL : ノーマル）
                    outlineActionGoTo2.setFlags(PtlOutline.ITEM_FLAG.FLAG_NORMAL);
                    // PDF表示時の子アウトラインをオープンするかどうかの設定
                    outlineActionGoTo2.setOpen(false);
                    // 子アウトラインの追加
                    outlineActionGoToTop.appendLastChild(outlineActionGoTo2);

                    // URIアクション    -----------------------------------
                    using (PtlOutline outlineActionURI = new PtlOutline())
                    {
                        // アウトラインタイトル文字列を設定
                        outlineActionURI.setTitle("http://www.antenna.co.jp/");
                        // アクション
                        // PtlActionURI : URIアクション
                        using (PtlActionURI actionuri = new PtlActionURI())
                        {
                            // URIを設定
                            actionuri.setURI("http://www.antenna.co.jp/");
                            // アクションの設定
                            outlineActionURI.setAction(actionuri);
                        }
                        // アウトラインタイトルの色を設定
                        using (PtlColorDeviceRGB color = new PtlColorDeviceRGB(0.0f, 0.0f, 1.0f))
                        {
                            outlineActionURI.setColor(color);
                        }
                        // アウトラインフラグを設定
                        // (FLAG_BOLD : 太字　と、　FLAG_ITALIC : イタリック　の論理和)
                        outlineActionURI.setFlags(PtlOutline.ITEM_FLAG.FLAG_BOLD | PtlOutline.ITEM_FLAG.FLAG_ITALIC);
                        // PDF表示時の子アウトラインをオープンするかどうかの設定
                        // （false : 新ウィンドウでオープンしない）
                        outlineActionURI.setOpen(false);
                        // Bookmark sample-1の兄弟アウトラインとして追加
                        outlineActionGoTo2.appendNextSibling(outlineActionURI);
                    }
                }
            }
        }
    }
}
